@@ -148,6 +148,18 @@ class ActionManager {
         });
     }
 
+    makeKey(length) {
+        let result = '';
+        const characters = 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789';
+        const charactersLength = characters.length;
+        let counter = 0;
+        while (counter < length) {
+            result += characters.charAt(Math.floor(Math.random() * charactersLength));
+            counter += 1;
+        }
+        return result;
+    }
+
     /**
      * Submit an action to the server.
      * @param {string} actionName - The name of the action.
@@ -164,7 +176,7 @@ class ActionManager {
         }
 
         // generate actionLogKey
-        let actionLogKey = window.crypto.randomUUID();
+        let actionLogKey = this.makeKey(32);
 
         // init actionLogClient
         this.actionLogClient = new WebSocket("ws://" + window.location.host + "/" + window.location.pathname.split("/")[1] + "/ws/action_log/" + actionLogKey);
@@ -177,7 +189,7 @@ class ActionManager {
         query.append("name", actionName);
 
         // append actionLogKey to query
-        query.append("actionLogKey", actionLogKey);
+        query.append("action_log_key", actionLogKey);
 
         this.appendQueryParams(query, element);
         let url = baseUrl + "?" + query.toString();
@@ -515,7 +527,12 @@ class ActionManager {
             });
 
             // set form abort button text
-            formAbort.text(formBtnAbortText);
+            if (formBtnAbortText === null) {
+                formAbort.hide();
+            } else {
+                formAbort.show();
+                formAbort.text(formBtnAbortText);
+            }
 
             // set form abort button action
             formAbort.off("click");
