@@ -1,6 +1,6 @@
 from jinja2 import PackageLoader
 
-from wiederverwendbar.starlette_admin.admin import MultiPathAdmin
+from wiederverwendbar.starlette_admin.multi_path.admin import MultiPathAdmin
 
 
 class DropDownIconViewAdmin(MultiPathAdmin):
