@@ -1,7 +1,7 @@
 from jinja2 import PackageLoader
 from starlette_admin.contrib.mongoengine import Admin as MongoengineAdmin
 
-from wiederverwendbar.starlette_admin.admin import MultiPathAdmin
+from wiederverwendbar.starlette_admin.multi_path.admin import MultiPathAdmin
 
 
 class BooleanAlsoAdmin(MongoengineAdmin, MultiPathAdmin):
